# :revolving_hearts: Love Term :airplane:
Love term is terminal package for LDR couples to just make a few things easier, give you ideas, and add some more romance to your relationship

### Installation
**Note:** Only runs on MacOS (as far as I know) and was developed in Python 2.7

```sh
$ pip install loveterm
```

requirements for loveterm which can be installed with pip:

```sh
requests==2.18.4
beautifulsoup4==4.6.0
```


## Commands:

##### For Dates:

  - Type `loveterm setdate` to log any important dates you want to save like meeting times
  - Type `loveterm dates` to see all logged dates
  - Type `loveterm countdown` to see how many days are left until those special moments!
  - Type `loveterm delete` to delete logged dates

##### Other Cute Stuff:

  - Type `loveterm send` to send an email to your lover with a cute message!
  - Type `loveTerm getsong` to get a romantic song from Michelle Obama's Valentines playlist
  - Type `loveTerm getcute` to get an inspirational and cute message
  - Type `loveTerm getidea` for a cute LDR-friendly date suggestion

License
----

MIT
